==> sandra-entities-1.3.0-sources.jar: com/cybelia/sandra/entities/trace/SuiviUsine.java <==
package com.cybelia.sandra.entities.trace;

import com.cybelia.sandra.entities.Usine;
import java.util.Collection;
import java.util.Date;
import org.nuiton.topia.persistence.TopiaEntity;

public interface SuiviUsine extends TopiaEntity {

    String PROPERTY_CREATION_ORDRE = "creationOrdre";

    String PROPERTY_NOUVELLE_ORDRE = "nouvelleOrdre";

    String PROPERTY_DATE_ENTREE = "dateEntree";

    String PROPERTY_DATE_SORTIE = "dateSortie";

    String PROPERTY_TEMPS_CHARGEMENT = "tempsChargement";

    String PROPERTY_HEURE_CHARGEMENT = "heureChargement";

    String PROPERTY_CHARGE_PAR = "chargePar";

    String PROPERTY_DATE_CHARGEMENT_PREVUE = "dateChargementPrevue";

    String PROPERTY_SUIVI_LIGNE_PRODUIT = "suiviLigneProduit";

    String PROPERTY_C_RUSINE = "cRUsine";

    String PROPERTY_USINE = "usine";

    void setCreationOrdre(int creationOrdre);

    int getCreationOrdre();

    void setNouvelleOrdre(int nouvelleOrdre);

    int getNouvelleOrdre();

    void setDateEntree(Date dateEntree);

    Date getDateEntree();

    void setDateSortie(Date dateSortie);

    Date getDateSortie();

    void setTempsChargement(Date tempsChargement);

    Date getTempsChargement();

    void setHeureChargement(Date heureChargement);

    Date getHeureChargement();

    void setChargePar(int chargePar);

    int getChargePar();

    void setDateChargementPrevue(Date dateChargementPrevue);

    Date getDateChargementPrevue();

    void addSuiviLigneProduit(SuiviLigneProduit suiviLigneProduit);

    void addAllSuiviLigneProduit(Collection<SuiviLigneProduit> suiviLigneProduit);

    void setSuiviLigneProduit(Collection<SuiviLigneProduit> suiviLigneProduit);

    void removeSuiviLigneProduit(SuiviLigneProduit suiviLigneProduit);

    void clearSuiviLigneProduit();

    Collection<SuiviLigneProduit> getSuiviLigneProduit();

    SuiviLigneProduit getSuiviLigneProduitByTopiaId(String topiaId);

    int sizeSuiviLigneProduit();

    boolean isSuiviLigneProduitEmpty();

    void setCRUsine(CRUsine cRUsine);

    CRUsine getCRUsine();

    void setUsine(Usine usine);

    Usine getUsine();

} //SuiviUsine

==> sandra-entities-2.1-sources.jar: com/cybelia/sandra/entities/trace/SuiviUsine.java <==
package com.cybelia.sandra.entities.trace;

import com.cybelia.sandra.entities.Usine;
import java.util.Collection;
import java.util.Date;
import org.nuiton.topia.persistence.TopiaEntity;

public interface SuiviUsine extends TopiaEntity {

    String PROPERTY_CREATION_ORDRE = "creationOrdre";

    String PROPERTY_NOUVELLE_ORDRE = "nouvelleOrdre";

    String PROPERTY_DATE_ENTREE = "dateEntree";

    String PROPERTY_DATE_SORTIE = "dateSortie";

    String PROPERTY_TEMPS_CHARGEMENT = "tempsChargement";

    String PROPERTY_HEURE_CHARGEMENT = "heureChargement";

    String PROPERTY_CHARGE_PAR = "chargePar";

    String PROPERTY_DATE_CHARGEMENT_PREVUE = "dateChargementPrevue";

    String PROPERTY_SUIVI_LIGNE_PRODUIT = "suiviLigneProduit";

    String PROPERTY_C_RUSINE = "cRUsine";

    String PROPERTY_USINE = "usine";

    void setCreationOrdre(int creationOrdre);

    int getCreationOrdre();

    void setNouvelleOrdre(int nouvelleOrdre);

    int getNouvelleOrdre();

    void setDateEntree(Date dateEntree);

    Date getDateEntree();

    void setDateSortie(Date dateSortie);

    Date getDateSortie();

    void setTempsChargement(Date tempsChargement);

    Date getTempsChargement();

    void setHeureChargement(Date heureChargement);

    Date getHeureChargement();

    void setChargePar(int chargePar);

    int getChargePar();

    void setDateChargementPrevue(Date dateChargementPrevue);

    Date getDateChargementPrevue();

    void addSuiviLigneProduit(SuiviLigneProduit suiviLigneProduit);

    void addAllSuiviLigneProduit(Collection<SuiviLigneProduit> suiviLigneProduit);

    void setSuiviLigneProduit(Collection<SuiviLigneProduit> suiviLigneProduit);

    void removeSuiviLigneProduit(SuiviLigneProduit suiviLigneProduit);

    void clearSuiviLigneProduit();

    Collection<SuiviLigneProduit> getSuiviLigneProduit();

    SuiviLigneProduit getSuiviLigneProduitByTopiaId(String topiaId);

    int sizeSuiviLigneProduit();

    boolean isSuiviLigneProduitEmpty();

    void setcRUsine(CRUsine cRUsine);

    CRUsine getcRUsine();

    void setUsine(Usine usine);

    Usine getUsine();

    CRUsine getCRUsine();

    void setCRUsine(CRUsine crUsine);

    boolean isActif();

} //SuiviUsine
